@@ -115,18 +115,12 @@ class Client:
         patient_mrn = patient_data['MRN']
         patient_partition = patient_data['PATIENT_PARTITION']
         patient_id = Helpers.patient_hash(self.client_uuid, [patient_mrn])[0]
-        start = time.time()
         patient_row = self.__get_patient_in_patients_table(
             patient_mrn, patient_id, patient_partition)
-        finish = time.time()
-        print('time to get patient: ' + str(finish - start) + ' seconds')
-        start = time.time()
+
         result = self.__insert_data_to_patients_table(patient_data,
                                                       patient_row,
                                                       overwrite=overwrite)
-        finish = time.time()
-        print('time to upload patient data: ' + str(finish - start) +
-              ' seconds')
         return result
 
     def __get_patient_in_patients_table(self, patient_mrn, patient_id,
@@ -144,7 +138,8 @@ class Client:
                     FROM `' + self.patient_table_name + '`\
                     WHERE MRN =\'' + patient_mrn + '\'\
                     AND PATIENT_ID =\'' + patient_id + '\'\
-                    AND PATIENT_PARTITION =' + str(patient_partition)
+                    AND (PATIENT_PARTITION =' + str(patient_partition) + '\
+                    OR PATIENT_PARTITION = 4000)'
 
         rows = BigQuery.Wrapper().perform_query(query)
 
@@ -178,11 +173,16 @@ class Client:
         '''
         if patient_row is not None:
             # patient exists, updated patient in table
+            # check if patient partition is 4000
+            if patient_row.get('PATIENT_PARTITION') == 4000:
+                patient_data['PATIENT_PARTITION'] = 4000
+
             return Update.Client(
                 self.client_uuid).update_patient_in_patient_table(
                     patient_data, patient_row, overwrite=overwrite)
         elif overwrite == False:
-            # if not append to PATIENTS table
+            # patient ID has never been inserted, add to todays partition
+            patient_data['PATIENT_PARTITION'] = 4000
             return self.__add_data_to_patient_table(patient_data)
         else:
             Helpers.print_error("patient does not exist cannot update")
