@@ -11,7 +11,7 @@ from indxdatalaketools.DataLakeGlobals import DATASET_OWNER
 from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
 from indxdatalaketools.Helpers import print_error
 from google.cloud.bigquery.enums import EntityTypes
-from indxdatalaketools.GoogleClientWrappers.retry_decorator import retry_decorator
+from indxdatalaketools.Helpers import retry_decorator
 
 
 class Wrapper:
