@@ -6,7 +6,7 @@
 from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
 from google.api_core.exceptions import ServiceUnavailable
 from indxdatalaketools.Helpers import print_error
-from indxdatalaketools.GoogleClientWrappers.retry_decorator import retry_decorator
+from indxdatalaketools.Helpers import retry_decorator
 
 
 class Wrapper:
