@@ -9,10 +9,16 @@ import csv
 import hashlib
 import sys
 import os
-
+import time
+from google.api_core.exceptions import ServiceUnavailable
 import requests
 
 
+class PropertiesTableException(BaseException):
+    """Raised when the input value is too small"""
+    pass
+
+
 def read_batch_file(file_name: str) -> list:
     ''' Reads the contents of the batch file and returns a list of lists
 
@@ -224,6 +230,49 @@ def determine_json_structure(json_data):
         return result
 
 
+def retry_decorator(retries: int = 5, backoff_in_seconds: int = 1):
+    ''' Decorator to retry a function on a 503 ServiceUnavailable exception
+
+    This retry decorator uses exponential back off with a default value of 5 retries
+    and 1 second for backoff
+
+    Args:
+        func (function): the function we wish to use the retry strategy on
+        retries (int): optional paramter with the number of retries for the client call
+        backoff_in_seconds (int): optional parameter the number of seconds to wait initially
+
+    Returns:
+        function: the wrapped function
+    '''
+
+    def rd(func):
+
+        def retry(*args, **kwargs):
+            for x in range(0, retries):
+                try:
+                    returned_value = func(*args, **kwargs)
+                    break
+                except ServiceUnavailable:
+                    # exponential backoff
+                    sleep = (backoff_in_seconds * 2**x)
+                    time.sleep(sleep)
+                except requests.exceptions.HTTPError:
+                    sleep = (backoff_in_seconds * 2**x)
+                    time.sleep(sleep)
+                    returned_value = None
+                except PropertiesTableException:
+                    sleep = (backoff_in_seconds * 2**x)
+                    time.sleep(sleep)
+                    returned_value = None
+
+            return returned_value
+
+        return retry
+
+    return rd
+
+
+@retry_decorator()
 def create_get_request(url, params={}, headers={}):
     """
         Creates a request to the url and returns the response in a dictionary
@@ -240,9 +289,10 @@ def create_get_request(url, params={}, headers={}):
         return r.json()
     except requests.exceptions.HTTPError as err:
         print_error('get request to ' + url + ' failed ' + str(err))
-        return None
+        raise requests.exceptions.HTTPError()
 
 
+@retry_decorator()
 def create_post_request(url, body, params={}, headers={}):
     """
         Creates a request to the url and returns the response in a dictionary
@@ -260,4 +310,4 @@ def create_post_request(url, body, params={}, headers={}):
         return r.json()
     except requests.exceptions.HTTPError as err:
         print_error('post request to ' + url + ' failed ' + str(err))
-        return None
\ No newline at end of file
+        raise requests.exceptions.HTTPError()
\ No newline at end of file
